@@ -1,5 +1,5 @@
 package Getopt::EX::LabeledParam;
-use version; our $VERSION = version->declare("v1.23.3");
+use version; our $VERSION = version->declare("v1.24.0");
 
 use v5.14;
 use warnings;
@@ -24,7 +24,7 @@ sub new {
 	LIST => [],
     }, $class;
 
-    configure $obj @_;
+    $obj->configure(@_) if @_;
 
     $obj;
 }
@@ -109,10 +109,26 @@ sub load_params {
 		}
 	    }
 	    map {
-		if (!/\W/ and $obj->{NEWLABEL}) {
-		    $_;
-		} else {
-		    match_glob($_, keys %{$obj->{HASH}})
+		# plain label
+		if (not /\W/) {
+		    if (exists $obj->{HASH}->{$_}) {
+			$_;
+		    } else {
+			if ($obj->{NEWLABEL}) {
+			    $_;
+			} else {
+			    warn "$_: Unknown label\n";
+			    ();
+			}
+		    }
+		}
+		# wild card
+		else {
+		    my @labels = match_glob($_, keys %{$obj->{HASH}});
+		    if (@labels == 0) {
+			warn "$_: Unmatched label\n";
+		    }
+		    @labels;
 		}
 	    }
 	    @$_;
